@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-from talon.quotations import register_xpath_extensions
+from taloncb.quotations import register_xpath_extensions
 try:
     from talon import signature
     ML_ENABLED = True
@@ -9,5 +9,5 @@ except ImportError:
 
 def init():
     register_xpath_extensions()
-    # if ML_ENABLED:
-    #     signature.initialize()
+    if ML_ENABLED:
+        signature.initialize()
